@@ -120,8 +120,12 @@ class HomeChargerStatus:
             reminder_time=json.get("plug_in_reminder_time", ""),
             model=json.get("model", ""),
             mac_address=json.get("mac_address", "00:00:00:00:00:00"),
-            amperage_limit=json.get("charge_amperage_setting", {}).get("charge_limit", 0),
-            possible_amperage_limits=json.get("charge_amperage_setting", {}).get("possible_charge_limit", 0),
+            amperage_limit=json.get("charge_amperage_setting", {}).get(
+                "charge_limit", 0
+            ),
+            possible_amperage_limits=json.get("charge_amperage_setting", {}).get(
+                "possible_charge_limit", 0
+            ),
         )
 
 
